==> certmanager-model-v1alpha2-6.6.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/CertificatePrivateKeyFluentImpl.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CertificatePrivateKeyFluentImpl<A extends CertificatePrivateKeyFluent<A>> extends BaseFluent<A> implements CertificatePrivateKeyFluent<A>{
  public CertificatePrivateKeyFluentImpl() {
  }
  public CertificatePrivateKeyFluentImpl(CertificatePrivateKey instance) {
    this.withRotationPolicy(instance.getRotationPolicy()); 
  }
  private String rotationPolicy;
  public String getRotationPolicy() {
    return this.rotationPolicy;
  }
  public A withRotationPolicy(String rotationPolicy) {
    this.rotationPolicy=rotationPolicy; return (A) this;
  }
  public Boolean hasRotationPolicy() {
    return this.rotationPolicy != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CertificatePrivateKeyFluentImpl that = (CertificatePrivateKeyFluentImpl) o;
    if (rotationPolicy != null ? !rotationPolicy.equals(that.rotationPolicy) :that.rotationPolicy != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(rotationPolicy,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (rotationPolicy != null) { sb.append("rotationPolicy:"); sb.append(rotationPolicy); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> certmanager-model-v1alpha2-6.7.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/CertificatePrivateKeyFluentImpl.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CertificatePrivateKeyFluentImpl<A extends CertificatePrivateKeyFluent<A>> extends BaseFluent<A> implements CertificatePrivateKeyFluent<A>{
  public CertificatePrivateKeyFluentImpl() {
  }
  public CertificatePrivateKeyFluentImpl(CertificatePrivateKey instance) {
    if (instance != null) {
      this.withRotationPolicy(instance.getRotationPolicy());
    }
  }
  private String rotationPolicy;
  public String getRotationPolicy() {
    return this.rotationPolicy;
  }
  public A withRotationPolicy(String rotationPolicy) {
    this.rotationPolicy=rotationPolicy; return (A) this;
  }
  public Boolean hasRotationPolicy() {
    return this.rotationPolicy != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CertificatePrivateKeyFluentImpl that = (CertificatePrivateKeyFluentImpl) o;
    if (!java.util.Objects.equals(rotationPolicy, that.rotationPolicy)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(rotationPolicy,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (rotationPolicy != null) { sb.append("rotationPolicy:"); sb.append(rotationPolicy); }
    sb.append("}");
    return sb.toString();
  }
  
}
